@@ -1,5 +1,5 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '1.12';
+$Selenium::Remote::RemoteConnection::VERSION = '1.20';
 #ABSTRACT: Connect to a selenium server
 
 use Moo;
@@ -72,6 +72,14 @@ sub request {
     if ($url =~ m/^http/g) {
         $fullurl = $url;
     }
+    elsif ($url =~ m/^\//) {
+        # This is used when we get a 302 Redirect with a Location header.
+        $fullurl =
+           "http://"
+          . $self->remote_server_addr . ":"
+          . $self->port
+          . $url;
+    }
     elsif ($url =~ m/grid/g) {
         $fullurl =
             "http://"
@@ -152,6 +160,10 @@ sub _process_response {
                 }
                 else {
                     $data->{'cmd_return'} = $decoded_json->{'value'};
+                    if (ref($data->{cmd_return}) eq 'HASH'
+                        && exists $data->{cmd_return}->{sessionId}) {
+                        $data->{sessionId} = $data->{cmd_return}->{sessionId};
+                    }
                 }
             }
             else {
@@ -183,7 +195,7 @@ Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 1.12
+version 1.20
 
 =head1 SEE ALSO
 
